==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ro.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarii",
    "Unknown user" : "Utilizator necunoscut",
    "New comment …" : "Comentariu nou...",
    "Delete comment" : "Șterge comentariul",
    "Post" : "Postează",
    "Cancel" : "Anulează",
    "Edit comment" : "Editează comentariul",
    "[Deleted user]" : "[Utilizator șters]",
    "No comments yet, start the conversation!" : "Nici un comentariu încă, începe conversația!",
    "More comments …" : "Mai multe comentarii...",
    "Save" : "Salvează",
    "Allowed characters {count} of {max}" : "Caractere admise {count} din {max}",
    "Error occurred while retrieving comment with id {id}" : "Eroare la returnarea comentariului cu id-ul {id}",
    "Error occurred while updating comment with id {id}" : "Eroare la actualizarea comentariului cu id-ul {id}",
    "Error occurred while posting comment" : "Eroare la postarea comentariului",
    "_%n unread comment_::_%n unread comments_" : ["%n comentariu necitit","%n comentarii necitite","%n comentarii necitite"],
    "Comment" : "Comentariu",
    "You commented" : "Ai comentat",
    "%1$s commented" : "%1$s a comentat",
    "{author} commented" : " {author} a comentat",
    "You commented on %1$s" : "Ai comentat la %1$s",
    "You commented on {file}" : "Ai comentat la {file}",
    "%1$s commented on %2$s" : "%1$s a comentat la %2$s",
    "{author} commented on {file}" : " {author} a comentat la {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarii</strong> la fișiere",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un utilizator (momentan) șters te-a menționat într-un comentariu la ”%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un utilizator (momentan) șters te-a menționat într-un comentariu la ”{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te-a menționat într-un comentariu la ”%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te-a menționat într-un comentariu la ”{file}”"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ro.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarii",
    "Unknown user" : "Utilizator necunoscut",
    "New comment …" : "Comentariu nou...",
    "Delete comment" : "Șterge comentariul",
    "Post" : "Postează",
    "Cancel" : "Anulează",
    "Edit comment" : "Editează comentariul",
    "[Deleted user]" : "[Utilizator șters]",
    "No comments yet, start the conversation!" : "Nici un comentariu încă, începe conversația!",
    "More comments …" : "Mai multe comentarii...",
    "Save" : "Salvează",
    "Allowed characters {count} of {max}" : "Caractere admise {count} din {max}",
    "Error occurred while retrieving comment with id {id}" : "Eroare la returnarea comentariului cu id-ul {id}",
    "Error occurred while updating comment with id {id}" : "Eroare la actualizarea comentariului cu id-ul {id}",
    "Error occurred while posting comment" : "Eroare la postarea comentariului",
    "_%n unread comment_::_%n unread comments_" : ["%n comentariu necitit","%n comentarii necitite","%n comentarii necitite"],
    "Comment" : "Comentariu",
    "You commented" : "Ai comentat",
    "%1$s commented" : "%1$s a comentat",
    "{author} commented" : " {author} a comentat",
    "You commented on %1$s" : "Ai comentat la %1$s",
    "You commented on {file}" : "Ai comentat la {file}",
    "%1$s commented on %2$s" : "%1$s a comentat la %2$s",
    "{author} commented on {file}" : " {author} a comentat la {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarii</strong> la fișiere",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te-a menționat într-un comentariu la ”%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te-a menționat într-un comentariu la ”{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un utilizator (momentan) șters te-a menționat într-un comentariu la ”%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un utilizator (momentan) șters te-a menționat într-un comentariu la ”{file}”"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
